gilly/constant
Values
pub const header_comment: String
Template for the header comment in generated code files. Matches the Go’s generated files conventions so that git identifies this as a generated file and ignores it in diffs by default.
TODO(cyclimse): does not work on GitHub for some reason, only GitLab. Should investigate.
Reference: https://github.com/golang/go/issues/13560#issuecomment-288457920
pub const supported_file_types: List(String)
Supported file types for input OpenAPI specifications. Ideally, we should support YAML as well, but Gleam has no YAML parsing libraries ATM.
See: https://github.com/lpil/cymbal/pull/2